/**
 * JASMINe
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ProbeConfigSaveCommand.java 9710 2012-01-31 15:09:06Z danesa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.probe.shell;


import java.io.PrintStream;

import org.apache.felix.ipojo.annotations.Component;
import org.apache.felix.ipojo.annotations.Provides;
import org.apache.felix.ipojo.annotations.Requires;
import org.apache.felix.shell.Command;
import org.ow2.jasmine.probe.JasmineProbeException;
import org.ow2.jasmine.probe.JasmineProbeManager;

/**
 * Implements probe-config-save command.
 * @author danesa
 */
@Component(name="ProbeConfigSaveCommand")
@Provides
public class ProbeConfigSaveCommand extends JasmineProbeCommand implements Command  {

    /**
     * command name
     */
    private String name = "probe-config-save";

    /**
     * command description
     */
    private String description = "Save JASMINe Probe configuration into a file";


    // ----------------------------------------------------------------------------
    // ipojo management
    // ----------------------------------------------------------------------------

    @Requires
    JasmineProbeManager probeManager = null;

    // ----------------------------------------------------------------------------
    // constructors
    // ----------------------------------------------------------------------------

    /**
     * Default Constructor
     */
    public ProbeConfigSaveCommand() {
        super();
        setParams(new ProbeConfigLoadSaveCommandParams());
    }

    // ----------------------------------------------------------------------------
    // org.apache.felix.shell.Command implementation
    // ----------------------------------------------------------------------------

    /**
     * Returns the name of the command that is implemented by the interface.
     * The command name should not contain whitespace and should also be unique.
     * @return the name of the command.
     */
    public String getName() {
        return name;
    }

    /**
     * Returns a short description of the command; this description should be as short as possible.
     * This information is used when generating the command help information.
     * @return a short description of the command.
     */
    public String getShortDescription() {
        return description;
    }

    public JasmineProbeManager getProbeManager() {
        return probeManager;
    }

    /**
     * Executes the command using the supplied command line, output print stream, and error print stream.
     * @param line the complete command line, including the command name.
     * @param out  the print stream to use for standard output.
     * @param err  the print stream to use for standard error.
     */
    public void execute(String line, PrintStream out, PrintStream err) {
        boolean validOptions = parseOptions(line, out, err);
        if (!validOptions) {
            err.println(getUsage());
            return;
        }

        ProbeConfigLoadSaveCommandParams params = (ProbeConfigLoadSaveCommandParams) getParams();

        String file = params.getFile();

        try {
            probeManager.saveConfig(file);
        } catch (JasmineProbeException e) {
            err.println(name + " failed");
            err.println(e);
            return;
        }
        out.println(name + " successfull");

        // reset params
        params.reset();

    }
}